#define MFBIMAGEGLYPHBLT xf1bppImageGlyphBltBlack
#define OPEQ &=~
#include "mfbmap.h"
#include "../../../mfb/mfbimggblt.c"
